=====
syned
=====

About
-----

SYNchrotron Elements Dictionary.

A python library to define the components  (sources, mirrors, crystals, etc.) of a synchrotron beamline and their positions.
They can be read/write to json files.
It is used by OASYS as a common tool to define sources and optical systems that are then exported to the different add-ons.


Documentation
-------------
https://syned.readthedocs.io/


Source repository
-----------------
https://github.com/oasys-kit/syned

Quick-installation
------------------

Syned can be installed with Python 3.x:

.. code-block:: console

    $ python -m pip install syned

Graphical user interface
------------------------

A graphical interface is available under Oasys:  https://github.com/oasys-kit/OASYS-SYNED

Reference
---------

Luca Rebuffi, Manuel Sanchez del Rio,
"Interoperability and complementarity of simulation tools for beamline design in the
OASYS environment,"
Proc. SPIE 10388, Advances in Computational Methods for X-Ray Optics IV, 1038808 (23 August 2017);
https://doi.org/10.1117/12.2274232

